@@ -33,19 +33,32 @@
 #'
 #' A permutation vector
 #' maps a set of \eqn{n} objects \eqn{\{O_1, O_2, ..., O_n\}}{{O_1, O_2, ..., O_n}} onto itself.
+#'
+#' __Ordering Representation:__
 #' In \pkg{seriation} we represent a permutation \eqn{\pi}{\pi}
-#' as a vector which lists the objects in their permuted order.
-#' For example, the permutation vector \eqn{\langle3, 1, 2\rangle}{<3, 1, 2>} indicates that in first position is the object with index 3 then the object with index 1 and finally
-#' the object with index 2.
-#' A permutation vector can be extracted from a permutation vector object
-#' via [get_order()]. Such a permutation vector can be directly used
+#' as a vector which lists the objects' indices in their permuted order. This can
+#' be seen as replacing the object in position \eqn{i} with the object
+#' in position \eqn{\pi(i)}.
+#' For example, the permutation vector \eqn{\langle3, 1, 2\rangle}{<3, 1, 2>} indicates that in
+#' first position is the object with index 3 then the object with index 1 and finally
+#' the object with index 2. This representation is often called a (re)arrangement or ordering.
+#' The ordering can be extracted from a permutation vector object
+#' via [get_order()]. Such an ordering can be directly used
 #' to subset the list of original objects with `"["` to apply the permutation.
-#' __Note:__ An alternative way to specify a permutation is via a list of the ranks
-#' of the objects after permutation (see [get_rank()]).
+#'
+#' __Rank Representation:__
+#' An alternative way to specify a permutation is via a list of the ranks
+#' of the objects after permutation. This representation is often called
+#' a map or substitution. Ranks can be extracted from a permutation vector using [get_rank()].
+#'
+#' __Permutation Matrix:__
+#' Another popular representation is a permutation matrix which performs
+#' permutations using matrix multiplication. A permutation matrix can be obtained
+#' using [get_permutation_matrix()].
 #'
 #' `ser_permutation_vector` objects are usually packed into
 #' a [ser_permutation] object
-#' which is a collection of \eqn{k} permutation vectors for \eqn{k}-mode data.
+#' which is a collection (a `list`) of \eqn{k} permutation vectors for \eqn{k}-mode data.
 #'
 #' The constructor `ser_permutation_vector()`
 #' checks if the permutation vector is valid
@@ -53,18 +66,25 @@
 #'
 #' @family permutation
 #'
-#' @param x,object an object which contains a permutation vector (currently an
-#'     integer vector or an object of class [hclust]). The value `NA`
-#'     creates an identity permutation.
+#' @param x,object an object if class  `ser_permutation_vector`.
+#'    Options for the constructor are:
+#'      (1) an integer permutation vector,
+#'      (2) an object of class [hclust],
+#'      (3) a numeric vector with a MDS configuration, or
+#'      (4) `NA` to indicate a identity permutation.
 #' @param method a string representing the method used to obtain the
 #'     permutation vector.
 #' @param ... further arguments.
 #'
-#' @returns  An object of class `ser_permutation_vector`.
+#' @returns The constructor `ser_permutation_vector()` returns an
+#'  object a `ser_permutation_vector`
 #' @author Michael Hahsler
 #'
 #' @examples
-#' p <- ser_permutation_vector(sample(10), "random")
+#' o <- structure(sample(10), names = paste0("X", 1:10))
+#' o
+#'
+#' p <- ser_permutation_vector(o, "random")
 #' p
 #'
 #' ## some methods
@@ -78,23 +98,30 @@
 #' r
 #' get_order(r)
 #'
-#' ## create a identity permutation vector (with unknown length)
+#' ## create a symbolic identity permutation vector (with unknown length)
+#' ## Note: This can be used to permute an object, but methods
+#' ##       like length and get_order are not available.
 #' ip <- ser_permutation_vector(NA)
 #' ip
-#'
 #' @keywords classes
 #' @export
 ser_permutation_vector <- function(x, method = NULL) {
   if (inherits(x, "ser_permutation_vector"))
     return(x)
 
-  if (inherits(x, "hclust") || inherits(x, "dendrogram")) {
+  if  (inherits(x, "hclust") || inherits(x, "dendrogram")) {
     # nothing to do
   } else if (length(x) == 1 && is.na(x)) {
     x <- NA_integer_
     attr(x, "method") <- "identity permutation"
-  } else if (is.numeric(x)) {
-    x <- as.integer(x)
+  } else if (is.integer(x)) { # permutation vector
+    # do nothing
+  } else if (is.numeric(x)) { # a configuration
+    ats <- attributes(x) ### preserve attributes
+    nm <- names(x)
+    x <- order(x)
+    attributes(x) <- ats
+    names(x) <- nm
   } else if (inherits(x, "ser_permutation") && length(x) == 1) {
     x <- x[[1]]
   } else {
@@ -131,7 +158,6 @@ rev.ser_permutation_vector <- function(x) {
 }
 
 
-## currently method is an attribute of permutation
 #' @rdname ser_permutation_vector
 #' @param printable a logical; prints "unknown" instead of `NULL` for non-existing methods.
 #' @export
@@ -143,7 +169,6 @@ get_method <- function(x, printable = FALSE) {
   method
 }
 
-
 ## print et al
 #' @rdname ser_permutation_vector
 #' @export
