@@ -1,5 +1,4 @@
 ### R code from vignette source 'seriation.Rnw'
-### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: seriation.Rnw:120-123
@@ -10,13 +9,13 @@ set.seed(1234)
 
 
 ###################################################
-### code chunk number 2: seriation.Rnw:1022-1023
+### code chunk number 2: seriation.Rnw:1025-1026
 ###################################################
 set.seed(1234)
 
 
 ###################################################
-### code chunk number 3: seriation.Rnw:1026-1032
+### code chunk number 3: seriation.Rnw:1029-1035
 ###################################################
 library("seriation")
 
@@ -27,14 +26,14 @@ d <- dist(x)
 
 
 ###################################################
-### code chunk number 4: seriation.Rnw:1038-1040
+### code chunk number 4: seriation.Rnw:1041-1043
 ###################################################
 o <- seriate(d)
 o
 
 
 ###################################################
-### code chunk number 5: seriation.Rnw:1051-1052
+### code chunk number 5: seriation.Rnw:1054-1055
 ###################################################
 head(get_order(o), 15)
 
@@ -52,7 +51,7 @@ pimage(d, o, main = "Reordered")
 
 
 ###################################################
-### code chunk number 8: seriation.Rnw:1077-1078
+### code chunk number 8: seriation.Rnw:1080-1081
 ###################################################
 cbind(random = criterion(d), reordered = criterion(d, o))
 
@@ -60,25 +59,25 @@ cbind(random = criterion(d), reordered = criterion(d, o))
 ###################################################
 ### code chunk number 9: pimage2
 ###################################################
-pimage(scale(x), main = "Random")
+pimage(scale(x), main = "Random", prop = FALSE)
 
 
 ###################################################
 ### code chunk number 10: pimage2-2
 ###################################################
 o_2mode <- c(o, NA)
-pimage(scale(x), o_2mode, main = "Reordered")
+pimage(scale(x), o_2mode, main = "Reordered", prop = FALSE)
 
 
 ###################################################
-### code chunk number 11: seriation.Rnw:1127-1129
+### code chunk number 11: seriation.Rnw:1130-1132
 ###################################################
 methods <- c("TSP","R2E", "ARSA", "HC", "GW", "OLO")
 o <- sapply(methods, FUN = function(m) seriate(d, m))
 
 
 ###################################################
-### code chunk number 12: seriation.Rnw:1132-1134
+### code chunk number 12: seriation.Rnw:1135-1137
 ###################################################
 timing <- sapply(methods, FUN = function(m) system.time(seriate(d, m)),
     simplify = FALSE)
@@ -103,7 +102,7 @@ for(i in 1:length(o)) {
 
 
 ###################################################
-### code chunk number 15: seriation.Rnw:1263-1265
+### code chunk number 15: seriation.Rnw:1266-1268
 ###################################################
 crit <- sapply(o, FUN = function(x) criterion(d, x))
 t(crit)
@@ -121,42 +120,45 @@ par(def.par)
 
 
 ###################################################
-### code chunk number 17: seriation.Rnw:1306-1308
+### code chunk number 17: seriation.Rnw:1309-1311
 ###################################################
-show_seriation_methods("dist")[1:3]
-show_seriation_methods("matrix")[1:3]
+list_seriation_methods("dist")
+list_seriation_methods("matrix")
 
 
 ###################################################
 ### code chunk number 18: seriation.Rnw:1315-1316
 ###################################################
-list_seriation_methods("dist")
+get_seriation_method("dist", name = "ARSA")
 
 
 ###################################################
-### code chunk number 19: seriation.Rnw:1332-1335
+### code chunk number 19: seriation.Rnw:1333-1339
 ###################################################
-seriation_method_reverse <- function(x, control = NULL) {
-           lapply(dim(x), function(n) rev(seq(n)))
+seriation_method_reverse <- function(x, control = NULL,
+                                     margin = seq_along(dim(x))) {
+          lapply(seq_along(dim(x)), function(i)
+            if (i %in% margin) rev(seq(dim(x)[i]))
+            else NA)
 }
 
 
 ###################################################
-### code chunk number 20: seriation.Rnw:1343-1348
+### code chunk number 20: seriation.Rnw:1347-1352
 ###################################################
-set_seriation_method("matrix", "Reverse", seriation_method_reverse,
+set_seriation_method("matrix", "New_Reverse", seriation_method_reverse,
     "Reverse identity order")
 
-set_seriation_method("array", "Reverse", seriation_method_reverse,
+set_seriation_method("array", "New_Reverse", seriation_method_reverse,
     "Reverse identity order")
 
 
 ###################################################
-### code chunk number 21: seriation.Rnw:1353-1360
+### code chunk number 21: seriation.Rnw:1357-1364
 ###################################################
-show_seriation_methods("matrix")
+list_seriation_methods("matrix")
 
-o <- seriate(matrix(1, ncol=3, nrow=4), "reverse")
+o <- seriate(matrix(1, ncol = 3, nrow = 4), "New_Reverse")
 o
 
 get_order(o, 1)
@@ -164,35 +166,35 @@ get_order(o, 2)
 
 
 ###################################################
-### code chunk number 22: seriation.Rnw:1394-1395
+### code chunk number 22: seriation.Rnw:1398-1399
 ###################################################
 x <- scale(x, center = FALSE)
 
 
 ###################################################
-### code chunk number 23: seriation.Rnw:1402-1403 (eval = FALSE)
+### code chunk number 23: seriation.Rnw:1406-1407 (eval = FALSE)
 ###################################################
-## hmap(x, margin =c(7, 4), cexCol=1, labRow = FALSE)
+## hmap(x, margin = c(7, 4), cexCol = 1, row_labels = FALSE)
 
 
 ###################################################
-### code chunk number 24: seriation.Rnw:1413-1414 (eval = FALSE)
+### code chunk number 24: seriation.Rnw:1417-1418 (eval = FALSE)
 ###################################################
 ## hmap(x, method = "MDS")
 
 
 ###################################################
-### code chunk number 25: seriation.Rnw:1424-1429
+### code chunk number 25: seriation.Rnw:1428-1433
 ###################################################
 #bitmap(file = "seriation-heatmap1.png", type = "pnggray",
 #    height = 6, width = 6, res = 300, pointsize=14)
 pdf(file = "seriation-heatmap1.pdf")
-hmap(x, margin = c(7, 4), labRow = FALSE, cexCol=1)
+hmap(x, margin = c(7, 4), row_labels = FALSE, cexCol = 1)
 tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 26: seriation.Rnw:1431-1434
+### code chunk number 26: seriation.Rnw:1435-1438
 ###################################################
 pdf(file = "seriation-heatmap2.pdf")
 hmap(x, method="MDS")
@@ -200,160 +202,172 @@ tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 27: seriation.Rnw:1500-1502
+### code chunk number 27: seriation.Rnw:1504-1506
 ###################################################
 data("Irish")
 orig_matrix <- apply(Irish[,-6], 2, rank)
 
 
 ###################################################
-### code chunk number 28: seriation.Rnw:1512-1517
+### code chunk number 28: seriation.Rnw:1516-1521
 ###################################################
 o <- c(
-    seriate(dist(orig_matrix, "minkowski", p = 1), method ="TSP"),
+    seriate(dist(orig_matrix, "minkowski", p = 1), method = "TSP"),
     seriate(dist(t(orig_matrix), "minkowski", p = 1), method = "TSP")
 )
 o
 
 
 ###################################################
-### code chunk number 29: seriation.Rnw:1522-1524 (eval = FALSE)
+### code chunk number 29: seriation.Rnw:1525-1530
+###################################################
+get_seriation_method("matrix", name = "heatmap")
+
+o <- seriate(orig_matrix, method = "heatmap", dist_fun = function(d) dist(d, "minkowski", p = 1),
+             seriation_method = "TSP")
+o
+
+
+###################################################
+### code chunk number 30: seriation.Rnw:1535-1537 (eval = FALSE)
 ###################################################
 ## bertinplot(orig_matrix)
 ## bertinplot(orig_matrix, o)
 
 
 ###################################################
-### code chunk number 30: bertin1
+### code chunk number 31: bertin1
 ###################################################
 bertinplot(orig_matrix)
 
 
 ###################################################
-### code chunk number 31: bertin2
+### code chunk number 32: bertin2
 ###################################################
 bertinplot(orig_matrix, o)
 
 
 ###################################################
-### code chunk number 32: binary1
+### code chunk number 33: binary1
 ###################################################
 data("Townships")
 
-bertinplot(Townships, options = list(panel=panel.squares, spacing = 0,
-    frame = TRUE))
+bertinplot(Townships, panel = panel.tiles)
 
 
 ###################################################
-### code chunk number 33: seriation.Rnw:1602-1604
+### code chunk number 34: seriation.Rnw:1614-1616
 ###################################################
 ## to get consistent results
 set.seed(5)
 
 
 ###################################################
-### code chunk number 34: binary2
+### code chunk number 35: binary2
 ###################################################
 o <- seriate(Townships, method = "BEA", control = list(rep = 10))
-bertinplot(Townships, o, options = list(panel=panel.squares, spacing = 0,
-    frame = TRUE))
+bertinplot(Townships, o, panel = panel.tiles)
 
 
 ###################################################
-### code chunk number 35: seriation.Rnw:1644-1645
+### code chunk number 36: seriation.Rnw:1655-1659
 ###################################################
-rbind(original = criterion(Townships), reordered = criterion(Townships, o))
+rbind(
+  original = criterion(Townships),
+  reordered = criterion(Townships, o)
+)
 
 
 ###################################################
-### code chunk number 36: seriation.Rnw:1712-1715
+### code chunk number 37: seriation.Rnw:1726-1730
 ###################################################
 data("iris")
-iris <- iris[sample(seq_len(nrow(iris))),]
-d <- dist(as.matrix(iris[-5]), method = "euclidean")
+iris <- iris[sample(seq_len(nrow(iris))), ]
+x_iris <- iris[, -5]
+d_iris <- dist(x_iris, method = "euclidean")
 
 
 ###################################################
-### code chunk number 37: dissplot1 (eval = FALSE)
+### code chunk number 38: dissplot1 (eval = FALSE)
 ###################################################
 ## ## plot original matrix
-## dissplot(d, method = NA)
+## dissplot(d_iris, method = NA)
 
 
 ###################################################
-### code chunk number 38: dissplot2 (eval = FALSE)
+### code chunk number 39: dissplot2 (eval = FALSE)
 ###################################################
 ## ## plot reordered matrix
-## dissplot(d, options = list(main = "Dissimilarity plot with seriation"))
+## dissplot(d_iris, main = "Dissimilarity plot with seriation")
 
 
 ###################################################
-### code chunk number 39: seriation.Rnw:1737-1743
+### code chunk number 40: seriation.Rnw:1752-1758
 ###################################################
 pdf(file = "seriation-dissplot1.pdf")
 ## plot original matrix
-dissplot(d, method = NA)
+dissplot(d_iris, method = NA)
 tmp <- dev.off()
 pdf(file = "seriation-dissplot2.pdf")
 ## plot reordered matrix
-dissplot(d, options = list(main = "Dissimilarity plot with seriation"))
+dissplot(d_iris, main = "Dissimilarity plot with seriation")
 tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 40: seriation.Rnw:1770-1771
+### code chunk number 41: seriation.Rnw:1785-1786
 ###################################################
 set.seed(1234)
 
 
 ###################################################
-### code chunk number 41: seriation.Rnw:1773-1775
+### code chunk number 42: seriation.Rnw:1788-1790
 ###################################################
-l <- kmeans(d, 10)$cluster
+l <- kmeans(x_iris, 10)$cluster
 #$
 
 
 ###################################################
-### code chunk number 42: dissplot3 (eval = FALSE)
+### code chunk number 43: dissplot3 (eval = FALSE)
 ###################################################
-## res <- dissplot(d, labels = l,
-##     options = list(main = "Dissimilarity plot - standard"))
+## res <- dissplot(d_iris, labels = l,
+##     main = "Dissimilarity plot - standard")
 
 
 ###################################################
-### code chunk number 43: seriation.Rnw:1788-1801
+### code chunk number 44: seriation.Rnw:1803-1816
 ###################################################
 pdf(file = "seriation-dissplot3.pdf")
 
 ## visualize the clustering
-res <- dissplot(d, labels = l,
-    options = list(main = "Dissimilarity plot - standard"))
+res <- dissplot(d_iris, labels = l,
+    main = "Dissimilarity plot - standard")
 tmp <- dev.off()
 
 
 pdf(file = "seriation-dissplot4.pdf")
 ## threshold
-plot(res, options = list(main = "Dissimilarity plot - threshold",
-    threshold = 1.5))
+plot(res, main = "Dissimilarity plot - threshold",
+    threshold = 3)
 
 tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 44: seriation.Rnw:1816-1817
+### code chunk number 45: seriation.Rnw:1831-1832
 ###################################################
 res
 
 
 ###################################################
-### code chunk number 45: seriation.Rnw:1836-1838 (eval = FALSE)
+### code chunk number 46: seriation.Rnw:1851-1853 (eval = FALSE)
 ###################################################
 ## plot(res, options = list(main = "Seriation - threshold",
-##     threshold = 1.5))
+##     threshold = 3))
 
 
 ###################################################
-### code chunk number 46: seriation.Rnw:1852-1855
+### code chunk number 47: seriation.Rnw:1867-1870
 ###################################################
 #names(res)
 table(iris[res$order, 5], res$label)[,res$cluster_order]
@@ -361,11 +375,11 @@ table(iris[res$order, 5], res$label)[,res$cluster_order]
 
 
 ###################################################
-### code chunk number 47: ruspini
+### code chunk number 48: ruspini
 ###################################################
-data("ruspini", package="cluster")
+data("ruspini", package = "cluster")
 d <- dist(ruspini)
-l <- kmeans(d, 3)$cluster
+l <- kmeans(ruspini, 3)$cluster
 dissplot(d, labels = l)
 
 
